==> shared_advanced-0.0.23.tar.gz: android/src/main/java/com/example/shared_advanced/SharedAdvancedPlugin.java <==
package com.example.shared_advanced;

import android.app.Activity;
import android.content.Intent;

import androidx.annotation.NonNull;

import io.flutter.app.FlutterActivity;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;


/** SharedAdvancedPlugin */
public class SharedAdvancedPlugin extends FlutterActivity implements FlutterPlugin, MethodCallHandler {

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    final MethodChannel channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "shared_advanced");
    channel.setMethodCallHandler(new SharedAdvancedPlugin());
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "shared_advanced");
    channel.setMethodCallHandler(new SharedAdvancedPlugin());
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
  }

  /**
   * Metodo que realiza lo que se pide desde el codigo DART
   *
   * @param call   methodCall
   * @param result Result
   */
  @Override
  public void onMethodCall(MethodCall call, @NonNull Result result) {
    String app, msg;

    switch (call.method){
      case "sharetoapp":
        app = call.argument("app");
        msg = call.argument("msg");
        sharetoapp(app,msg);
        break;
    }
  }

  private void sharetoapp(String app, String msg) {
    try{
      Intent intent = new Intent("pe.diegoveloper.printing");
      intent.setType("text/plain");
      intent.putExtra(android.content.Intent.EXTRA_TEXT,msg);
      startActivity(intent);
    }
    catch(Exception e){
      throw e;
    }

  }
}

==> shared_advanced-0.0.24.tar.gz: android/src/main/java/com/example/shared_advanced/SharedAdvancedPlugin.java <==
package com.example.shared_advanced;

import android.content.Intent;

import androidx.annotation.NonNull;

import io.flutter.app.FlutterActivity;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;


/** SharedAdvancedPlugin */
public class SharedAdvancedPlugin extends FlutterActivity implements FlutterPlugin, MethodCallHandler {

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    final MethodChannel channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "shared_advanced");
    channel.setMethodCallHandler(new SharedAdvancedPlugin());
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "shared_advanced");
    channel.setMethodCallHandler(new SharedAdvancedPlugin());
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
  }

  /**
   * Metodo que realiza lo que se pide desde el codigo DART
   *
   * @param call   methodCall
   * @param result Result
   */
  @Override
  public void onMethodCall(MethodCall call, @NonNull Result result) {
    String app, msg;

    switch (call.method){
      case "sharetoapp":
        app = call.argument("app");
        msg = call.argument("msg");
        sharetoapp(app,msg);
        break;
    }
  }

  private void sharetoapp(String app, String msg) {
    try{
      Intent intent = new Intent("pe.diegoveloper.printing");
      intent.setType("text/plain");
      intent.putExtra(android.content.Intent.EXTRA_TEXT,"ssda");
      startActivity(intent);
    }
    catch(Exception e){
      throw e;
    }

  }
}
